import axios from "axios";

import nProgress from "nprogress";
import "nprogress/nprogress.css";

// 在当前魔魁啊中引入store
import store from "@/store"

const requests = axios.create({
	// 根路径
	baseURL: "http://localhost:8080",
	// 代表请求超时的时间
	timeout: 5000,
});

//请求拦截器 config是当前跳转接口的所有信息
// 一般用来token身份认证（headers）和启动loading效果
requests.interceptors.request.use((config) => {

	// 每次发起axios都会让当前接口的请求头携带uuid游客身份令牌
	if (store.state.shopcart.uuid_token) {
		// userTemold是自定义属性 
		config.headers.userTempId = store.state.shopcart.uuid_token
	}

	// 获取本地存储的token值
	// let token = localStorage.getItem("TOKEN")
	let token = store.state.login.token
	if (token) {
		// console.log(token);
		config.headers.token = token
	}
	nProgress.start(); //进度条开始
	return config;  //固定写法 config包含当前接口的所有信息
});

// 响应拦截器 用来关闭请求拦截器中的方法(loading效果)
requests.interceptors.response.use((response) => {
	// 成功的回调函数:服务器响应数据回来以后，响应拦截器可以检测到,可以做一些事情
	nProgress.done(); // 进度条结束
	return response.data;
});
// ,
//   // 响应失败的回调函数
//   (error) => {
//     console.log(error);
//     return Promise.reject(new Error("false"));
//   }

export default requests;
